//  ANO PO "KSI", 2016

#include "CheckDBResult.h"

CheckDBResult::CheckDBResult(const QString& filename, const QString& hash, const CompareErrList& errList, QWidget *parent/*=nullptr*/) : QDialog(parent)
{
	setWindowTitle(tr("Check results"));
	
	createControls();

	m_pDBHashWidget->setFilename(filename);
	m_pDBHashWidget->setHash(hash);
	setCompareErrList(errList);
}

CheckDBResult::~CheckDBResult()
{

}

void CheckDBResult::setCompareErrList(const CompareErrList& errList)
{
	const bool errFound = errList.size() > 0;
	
	m_pLabelReport->setText(!errFound ? tr("Check result: no errors") : tr("Following errors were found:"));

	m_pErrTable->setVisible(errFound);
	m_pButtonCopy->setVisible(errFound);

	m_pErrTable->setCompareErrList(errList);
}

void CheckDBResult::createControls()
{
	QPushButton* pButtonClose = new QPushButton(style()->standardIcon(QStyle::SP_DialogCancelButton), tr("Close"));

	m_pButtonCopy = new QPushButton(QIcon(":/icons/copy.png"), tr("Copy report"));
	m_pButtonCopy->setToolTip(tr("Copy to clipboard"));
	m_pButtonCopy->setFixedSize(m_pButtonCopy->minimumSizeHint());

	QBoxLayout* pLayoutCmd = new QHBoxLayout;
	pLayoutCmd->addWidget(m_pButtonCopy);
	pLayoutCmd->addStretch(0);
	pLayoutCmd->addWidget(pButtonClose);

	QBoxLayout* pLayoutMain = new QVBoxLayout;
	pLayoutMain->addWidget(m_pDBHashWidget = new DBHashWidget);
	pLayoutMain->addWidget(m_pLabelReport = new QLabel);
	
	pLayoutMain->addWidget(m_pErrTable = new CheckErrTable,0);
	pLayoutMain->addLayout(pLayoutCmd);	

	setLayout(pLayoutMain);

	connect(m_pButtonCopy, &QPushButton::clicked, this, &CheckDBResult::copyToClipboard);
	connect(pButtonClose, &QPushButton::clicked, this, &CheckDBResult::accept);
}

void CheckDBResult::copyToClipboard()
{
	QApplication::clipboard()->setText(m_pErrTable->textReport());
}
